bread.layout package
====================

.. automodule:: bread.layout
   :members:
   :undoc-members:
   :show-inheritance:

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   bread.layout.components

Submodules
----------

bread.layout.base module
------------------------

.. automodule:: bread.layout.base
   :members:
   :undoc-members:
   :show-inheritance:

bread.layout.skeleton module
----------------------------

.. automodule:: bread.layout.skeleton
   :members:
   :undoc-members:
   :show-inheritance:
